Modify the display name of metadata. It is possible that the original
metadata name is not so informative e.g "orig.ident" or too long e.g.
"seurat_clusters" and users want to shorten the way they are displayed
on the shiny app. This function allows users to specify display names for
metadata i.e. the names that will be displayed on the shiny app. Note that
showLegend shows the display name instead of the actual name.
Arguments
- scConf
CellSight config data.table
- meta.to.mod
metadata for which to modify the display name. Users can either use the actual metadata column names or display names. Multiple metadata can be specified. It is reccomended to use the original metadata column names to reduce confusion.
- new.name
new display names for the corresponding metadata