Skip to contents

Shows the order in which metadata will be displayed in the shiny app. This helps users to decide if the display order is ok. If not, users can use reorderMeta to change the order in which metadata will be displayed.

Usage

showOrder(scConf)

Arguments

scConf

CellSight config data.table

Value

table showing the order in which metadata will be displayed

Author

John F. Ouyang

Examples

if (FALSE) { # \dontrun{
showOrder(scConf)
} # }