Remove a metadata from being included in the shiny app.
Arguments
- scConf
CellSight config data.table
- meta.to.del
metadata to delete. Users can either use the original metadata column names or display names. For more information regarding display name, see
?modMetaName. Multiple metadata can be specified.
Examples
if (FALSE) { # \dontrun{
scConf = delMeta(scConf, c("orig.ident"))
} # }