Shows the order in which metadata will be displayed in the shiny app. This
helps users to decide if the display order is ok. If not, users can use
reorderMeta to change the order in which metadata will be displayed.
Shows the order in which metadata will be displayed in the shiny app. This
helps users to decide if the display order is ok. If not, users can use
reorderMeta to change the order in which metadata will be displayed.